==> apache-skywalking-banyandb-java-client-0.2.0-src.tgz: apache-skywalking-banyandb-java-client-0.2.0/src/main/java/org/apache/skywalking/banyandb/v1/client/Or.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.skywalking.banyandb.v1.client;

import com.google.auto.value.AutoValue;
import org.apache.skywalking.banyandb.model.v1.BanyandbModel;

@AutoValue
public abstract class Or extends LogicalExpression {

    public static Or create(AbstractCriteria left, AbstractCriteria right) {
        return new AutoValue_Or(left, right);
    }

    @Override
    BanyandbModel.Criteria build() {
        return BanyandbModel.Criteria.newBuilder()
                .setLe(BanyandbModel.LogicalExpression.newBuilder()
                        .setLeft(left().build())
                        .setRight(right().build())
                        .setOp(BanyandbModel.LogicalExpression.LogicalOp.LOGICAL_OP_OR)
                        .build())
                .build();
    }
}

==> apache-skywalking-banyandb-java-client-0.9.1-src.tgz: apache-skywalking-banyandb-java-client-0.9.1/src/main/java/org/apache/skywalking/banyandb/v1/client/Or.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.skywalking.banyandb.v1.client;

import com.google.auto.value.AutoValue;
import org.apache.skywalking.banyandb.model.v1.BanyandbModel;

@AutoValue
public abstract class Or extends LogicalExpression {

    public static Or create(AbstractCriteria left, AbstractCriteria right) {
        return new AutoValue_Or(left, right);
    }

    @Override
    public BanyandbModel.Criteria build() {
        return BanyandbModel.Criteria.newBuilder()
                .setLe(BanyandbModel.LogicalExpression.newBuilder()
                        .setLeft(left().build())
                        .setRight(right().build())
                        .setOp(BanyandbModel.LogicalExpression.LogicalOp.LOGICAL_OP_OR)
                        .build())
                .build();
    }
}
